package
Version:
v0.0.0-...-b6abad4
Opens a new window with list of versions in this module.
Published: Feb 9, 2023
License: GPL-3.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Fact struct {
gorm.Model
Question string `json:"question" gorm:"text;not null;default:null`
Answer string `json:"answer" gorm:"text;not null;default:null`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.